# -*- coding: utf-8 -*-

"""PLOTTING ROUTINES.

This module contains submodules for plotting applications.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['cost_plot']
